#!/usr/bin/env python
#--------------------------------------------------------------------------
#
# Name: split_jit
#
# Description:
#       This script splits an associated jitter product into its
#       constituent jitter exposures, with each exposure in a separate
#	output file.
#
# Usage:
#       % split_jit infile
#
# History:
# Date     OPR      Who         Reason
# -------- -------- ---------- ---------------------------------------------
# 08/14/06 xxxxx    MSwam      tool for STIS DMS associations processing
#--------------------------------------------------------------------------
#
from pyraf import iraf
from pyraf.irafglobals import *
import shutil
import os
import sys
import glob
import opusutil
import pyfits
  
def split_jit(jitasn):
  primary_hdu = jitasn+"[0]"
  #
  # NEXTEND keywd will determine how many extensions to split out
  iraf.imgets(primary_hdu, "NEXTEND")
  nextend = iraf.imgets.value
  opusutil.PrintMsg('I',str(nextend)+" extensions found.")
  fd = pyfits.open(jitasn)

  for extension in range(1,int(nextend)+1):
    #
    # EXPNAME keywd will determine output filename
    expname = fd[extension].header["EXPNAME"].lower()
    expname_jit         = expname+"_jit.fits"
    expname_jit_primary = expname_jit+"[0]"
    #
    opusutil.PrintMsg('I','copying ext '+str(extension)+" to "+expname)
    opusutil.RemoveIfThere(expname_jit)

    hdr = pyfits.getheader(jitasn, 0)
    pyfits.writeto(expname_jit, None, hdr)

    try:
      data, hdr = pyfits.getdata(jitasn, extension, header=True)
      pyfits.append(expname_jit, data, hdr)
    except IndexError:
      opusutil.PrintMsg("E","Table "+jitasn+"["+str(extension)+"] appears empty.")

    # update FILENAME, NEXTEND keywords
    iraf.hedit (expname_jit_primary, "FILENAME", expname_jit,
                verify=no, show=no, update=yes)
    iraf.hedit (expname_jit_primary, "NEXTEND", "1",
                add=no, delete=no, verify=no, show=no, update=yes)
  #
  fd.close()

#------------------------------------------------------------------------
#
# SPLIT_JIT
#
#-----------------------------------------------------------------------
#
iraf.tables()

for jitasn in glob.glob("*0_jit.fits"):
  opusutil.PrintMsg('I','Splitting '+jitasn)
  #
  split_jit(jitasn)

sys.exit(0)  

